//
//  main.cpp
//  StrList
//
//  Created by Peter Dordal on 3/20/17.
//  Copyright © 2017 Comp 271. All rights reserved.
//

#include <iostream>
#include <string>

using namespace std;


/**
 * Class StrList represents a list of strings; it is our own version
 * of List<string>.
 * You create the list entries by using Add(), one at a time.
 * Once you have a list, you can print it.
 *
 * You can get the nth value with get(n), or set the nth value with set(n, val).
 * If n is out of range, get(n) returns 0 and set(n, val) does nothing.
 *
 */



class StrList {
    
private:
    // instance variables - replace the example below with your own
    string * elements;
    int currsize;
    int capacity;
    
public:
    /**
     * Constructor for objects of class StrList
     */
    StrList() {
        // initialise instance variables
        const int defaultCapacity = 5;
        currsize = 0;
        elements = new string[defaultCapacity];
        capacity = defaultCapacity;
    }
    
    ~StrList() {
        delete[] elements;	// the [] tells C++ it is deleting an array
    }
    
    /**
     * parameter constructor, allowing you to predefine a capacity.
     */
    StrList(int cap) {
        currsize = 0;
        capacity = cap;
        elements = new string[capacity];
    }
    
    /**
     * Add() Adds the value y to the list, at position currsize
     * (that is, at the end of the existing list).
     * The size of the list is incremented.
     * If pos = nums.length, there is no more room, so this version doesn't do anything;
     * THAT PART YOU ARE TO FIX!!
     */
    void Add(string y) {
        if (currsize == capacity) {
            cerr << "no more room to add " << y << endl;     // should not happen!
            return;
        }
        elements[currsize] = y;
        currsize += 1;      // or currsize++
    }
    
    // get nth value, with range check
    string get(int n) {
        if (n<0 || n >= currsize) {
            cerr << "Warning: StrList.get() called with out-of-range n = " << n << endl;
            return 0;
        }
        return elements[n];
    }
    
    // set nth value, with range check
    void set(int n, string val) {
        if (n<0 || n >= currsize) {
            cerr << "Warning: Strlist.set() called with out-of-range n = " << n << endl;
            return;
        }
        elements[n] = val;
    }
    
    int size() {
        return currsize;
    }
    
    
    void print() {
        int i=0;
        while (i<currsize) {
            cout << i << ":  " << elements[i] << endl;
            i++;
        }
    }
    
};

StrList words;

void initWords(){
    words.Add("apple");
    words.Add("blueberry");
    words.Add("cranberry");
    words.Add("daikon");
    words.Add("eggplant");
    words.Add("figs");
    words.Add("grapes");
    words.Add("hackberry");
    words.Add("iceberg");
    words.Add("jicama");
    words.Add("kale");
    words.Add("lemon");
    words.Add("mango");
    words.Add("nectarine");
    words.Add("onion");
    words.Add("persimmon");
    words.Add("quince");
    words.Add("rutabega");
    words.Add("sorrel");
    words.Add("tangerine");
}

int main() {
    //words = new StrList();
    initWords();
    StrList w2;
    int i;
    for (i = words.size()-1; i>=0; i--) w2.Add(words.get(i));
    
    for (i=0; i<w2.size(); i++) {
        cout << w2.get(i) << endl;
    }
}

